@@ -1,6 +1,5 @@
 from .docs import add_pkg_docs
 from .ipython import load_ipython_extension
-from .md_proxy import register_md
 from .report import Page, Report
 from .utils import relative_repo_root
 
@@ -10,5 +9,4 @@ __all__ = [
     "Page",
     "Report",
     "relative_repo_root",
-    "register_md",
 ]
