@@ -7,12 +7,13 @@ from copy import deepcopy
 from pathlib import Path
 from typing import Any, Dict, List, Optional
 
+import importlib_resources as imp_res
 import pandas as pd
 from mkreports.utils import func_ref, serialize_json, snake_to_text
 from pandas.api import types
 
 from .base import MdObj, comment_ids
-from .file import File, relpath_html
+from .file import File, relpath_html, store_asset_relpath
 from .md_proxy import register_md
 from .settings import PageInfo, Settings, merge_settings
 from .text import SpacedText
@@ -108,7 +109,9 @@ class DataTable(File):
         prettify_colnames: bool = True,
         add_header_filters: bool = False,
         yadcf_settings: Optional[dict] = None,
-        **kwargs,
+        table_kwargs: Optional[dict] = None,
+        downloads: bool = False,
+        table_settings: Optional[dict] = None,
     ):
         """
         Initialize the table using the DataTable javascript library.
@@ -126,6 +129,11 @@ class DataTable(File):
             add_header_filters (bool): Should header filters be added.
             yadcf_settings (Optional[dict]): Settings for the *yadcf* header filter plugin.
                 Overrides any automatic settings.
+            table_kwargs (Optional[dict]): Keyword args for the table
+                when serializing to json.
+            downloads (bool): Should download buttons be shown?
+            table_settings (Optional[dict]): Dictionary with the DataTable settings.
+                Anything set here will overwrite existing ones.
         """
         assert page_info.idstore is not None
         assert page_info.page_path is not None
@@ -139,13 +147,28 @@ class DataTable(File):
                 )
                 table = table.iloc[0:max_rows]
             # are not useful, but the rest gets set as 'data', which we need
-            table.to_json(path, orient="split", default_handler=str, **kwargs)
+            table.to_json(
+                path,
+                orient="split",
+                default_handler=str,
+                **(table_kwargs if table_kwargs is not None else {}),
+            )
 
             # Make sure the file is moved to the right place
             super().__init__(
                 path=path, page_info=page_info, allow_copy=True, use_hash=True
             )
 
+        javascript_settings = [
+            "https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js",
+            "https://cdn.datatables.net/1.11.3/js/jquery.dataTables.min.js",
+            "https://cdn.jsdelivr.net/gh/vedmack/yadcf@332407eeacbda299e6253530e24c15041b270227/dist/jquery.dataTables.yadcf.js",
+        ]
+        css_settings = [
+            "https://cdn.datatables.net/1.11.3/css/jquery.dataTables.min.css",
+            "https://cdn.jsdelivr.net/gh/vedmack/yadcf@332407eeacbda299e6253530e24c15041b270227/dist/jquery.dataTables.yadcf.css",
+        ]
+
         # prepare the table settings
         if prettify_colnames:
             col_set = {
@@ -171,6 +194,24 @@ class DataTable(File):
             "columns": [col_set[col] for col in table.columns],
         }
 
+        if downloads:
+            self.table_settings["buttons"] = ["copy", "csv", "excel", "pdf", "print"]
+            # self.table_settings["dom"] = "Bfrtlp"
+            self.table_settings["dom"] = "<lfr>t<Bp>"
+            css_settings.append(
+                "https://cdn.datatables.net/buttons/2.2.2/css/buttons.dataTables.min.css"
+            )
+            javascript_settings.extend(
+                [
+                    "https://cdn.datatables.net/buttons/2.2.2/js/dataTables.buttons.min.js",
+                    "https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js",
+                    "https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js",
+                    "https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js",
+                    "https://cdn.datatables.net/buttons/2.2.2/js/buttons.html5.min.js",
+                    "https://cdn.datatables.net/buttons/2.2.2/js/buttons.print.min.js",
+                ]
+            )
+
         datatable_id = page_info.idstore.next_id("datatable_id")
         body_html = inspect.cleandoc(
             f"""
@@ -179,9 +220,10 @@ class DataTable(File):
         )
 
         rel_table_path = relpath_html(self.path, page_info.page_path)
-        table_settings = copy.deepcopy(self.table_settings)
-        table_settings["ajax"] = str(rel_table_path)
-        settings_str = serialize_json(table_settings)
+        self.table_settings["ajax"] = str(rel_table_path)
+        # overwrite with given settigns if necessary
+        self.table_settings.update(table_settings if table_settings is not None else {})
+        settings_str = serialize_json(self.table_settings)
 
         # prepare the header script if necessary
         if self.add_header_filters:
@@ -209,15 +251,8 @@ class DataTable(File):
             page=dict(
                 # the following needs to be loaded in the header of the page, not the footer
                 # this enables activating the tables in the body
-                javascript=[
-                    "https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js",
-                    "https://cdn.datatables.net/1.11.3/js/jquery.dataTables.min.js",
-                    "https://cdn.jsdelivr.net/gh/vedmack/yadcf@332407eeacbda299e6253530e24c15041b270227/dist/jquery.dataTables.yadcf.js",
-                ],
-                css=[
-                    "https://cdn.datatables.net/1.11.3/css/jquery.dataTables.min.css",
-                    "https://cdn.jsdelivr.net/gh/vedmack/yadcf@332407eeacbda299e6253530e24c15041b270227/dist/jquery.dataTables.yadcf.css",
-                ],
+                javascript=javascript_settings,
+                css=css_settings,
             )
         )
 
@@ -291,7 +326,8 @@ class Tabulator(File):
         add_header_filters: bool = True,
         prettify_colnames: bool = True,
         col_settings: Optional[dict] = None,
-        **kwargs,
+        downloads: bool = False,
+        table_kwargs: Optional[dict] = None,
     ):
         """
 
@@ -307,6 +343,9 @@ class Tabulator(File):
             prettify_colnames (bool): Run column names through *snake_to_text*.
             col_settings (Optional[dict]): Column settings for tabulator, passed
                 as json to the Tabulator library. Overrides any internal settings created.
+            downloads (bool): Add download options.
+            table_kwargs (Optional[dict]): Keyword args for the table
+                when serializing to json.
         """
         assert page_info.idstore is not None
         assert page_info.page_path is not None
@@ -321,21 +360,18 @@ class Tabulator(File):
                     f"Table has {table.shape[0]} rows, but only {max_rows} allowed. Truncating."
                 )
                 table = table.iloc[0:max_rows]
-            table.to_json(path, orient="records", default_handler=str, **kwargs)
+            table.to_json(
+                path,
+                orient="records",
+                default_handler=str,
+                **(table_kwargs if table_kwargs is not None else {}),
+            )
 
             # Make sure the file is moved to the right place
             super().__init__(
                 path=path, page_info=page_info, allow_copy=True, use_hash=True
             )
 
-        # create the javascript file
-        self.min_max_filter_path = page_info.javascript_path / "min_max_filter.js"
-        self.min_max_filter_path.parent.mkdir(parents=True, exist_ok=True)
-        shutil.copy(
-            Path(__file__).parent / "tabulator_js" / "min_max_filter.js",
-            self.min_max_filter_path,
-        )
-
         # produce the column settings
         col_list = _create_col_settings_tabulator(
             table,
@@ -356,14 +392,14 @@ class Tabulator(File):
         )
         self.table_settings["columns"] = col_list
 
-        tabulator_id = page_info.idstore.next_id("tabulator_id")
+        used_ids = []
+        used_ids.append(tabulator_id := page_info.idstore.next_id("tabulator_id"))
         body_html = inspect.cleandoc(
             f"""
             <div id='{tabulator_id}' class='display'> </div>
             """
         )
 
-        rel_filter_path = relpath_html(self.min_max_filter_path, page_info.page_path)
         rel_table_path = relpath_html(self.path, page_info.page_path)
         table_settings = copy.deepcopy(self.table_settings)
         table_settings["ajaxURL"] = str(rel_table_path)
@@ -379,20 +415,77 @@ class Tabulator(File):
             </script>
             """
         )
+
+        javascript_settings = [
+            "https://unpkg.com/tabulator-tables@5.1.0/dist/js/tabulator.min.js",
+        ]
+        css_settings = [
+            "https://unpkg.com/tabulator-tables@5.1.0/dist/css/tabulator.min.css"
+        ]
+
+        if add_header_filters:
+            javascript_settings.append(
+                store_asset_relpath(Path("min_max_filter.js"), page_info)
+            )
+
+        if downloads:
+            # add the necessary things to enable downloads
+            # to the body
+            used_ids.append(csv_down_id := page_info.idstore.next_id("csv_down_id"))
+            used_ids.append(json_down_id := page_info.idstore.next_id("json_down_id"))
+            used_ids.append(xlsx_down_id := page_info.idstore.next_id("xslx_down_id"))
+            body_html = body_html + inspect.cleandoc(
+                f"""
+                    <div>
+                      <button class="tabulator-btn-dwn", id="{csv_down_id}">to CSV</button>
+                      <button class="tabulator-btn-dwn", id="{json_down_id}">to JSON</button>
+                      <button class="tabulator-btn-dwn", id="{xlsx_down_id}">to XLSX</button>
+                    </div>
+                    """
+            )
+            # to the back_html
+            split_back_html = back_html.split("\n")
+            split_back_html.insert(
+                -1,
+                inspect.cleandoc(
+                    f"""
+                    //trigger download of data.csv file
+                    $("#{csv_down_id}").click(function(){{
+                        table.download("csv", "data.csv");
+                    }});
+
+                    //trigger download of data.json file
+                    $("#{json_down_id}").click(function(){{
+                        table.download("json", "data.json");
+                    }});
+
+                    //trigger download of data.xlsx file
+                    $("#{xlsx_down_id}").click(function(){{
+                        table.download("xlsx", "data.xlsx", {{sheetName:"data"}});
+                    }});
+                    """
+                ),
+            )
+            back_html = "\n".join(split_back_html)
+            # to the settings
+            javascript_settings.append(
+                "https://oss.sheetjs.com/sheetjs/xlsx.full.min.js"
+            )
+            css_settings.append(
+                store_asset_relpath(Path("download_buttons.css"), page_info)
+            )
+
         settings = Settings(
             page=dict(
                 # the following needs to be loaded in the header of the page, not the footer
                 # this enables activating the tables in the body
-                javascript=[
-                    "https://unpkg.com/tabulator-tables@5.1.0/dist/js/tabulator.min.js",
-                    rel_filter_path,
-                ],
-                css=[
-                    "https://unpkg.com/tabulator-tables@5.1.0/dist/css/tabulator.min.css"
-                ],
+                javascript=javascript_settings,
+                css=css_settings,
             )
         )
 
         self._body = SpacedText(body_html, (2, 2))
-        self._back = SpacedText(back_html, (2, 2)) + comment_ids(tabulator_id)
+        self._back = SpacedText(back_html, (2, 2)) + "\n".join(
+            [str(comment_ids(this_id)) for this_id in used_ids]
+        )
         self._settings = settings
